@@ -29,8 +29,8 @@ impl User for BaseUser {
 }
 
 impl BaseUser { 
-    pub fn new(public_key: PublicKey, hashed_password: Arc<dyn HashedPassword>) -> Self { 
-        BaseUser{_public_key: public_key, _hashed_password: hashed_password}  
+    pub fn new(public_key: PublicKey, hashed_password: Arc<dyn HashedPassword>) -> Result<Self, std::io::Error> { 
+        Ok(BaseUser{_public_key: public_key, _hashed_password: hashed_password})
     }
 }
 
